ResilientStreamBuilder<T> class
A widget that subscribes to a Stream and automatically reconnects on error,
applying a ResiliencePipeline to each re-subscription attempt.
Example:
ResilientStreamBuilder<ChatMessage>(
streamFactory: () => chatService.messageStream(),
builder: (context, snapshot) {
if (snapshot.isLoading) return const CircularProgressIndicator();
if (snapshot.hasError) return ErrorView(error: snapshot.error);
return MessageTile(message: snapshot.data!);
},
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ResilientStreamBuilder
Constructors
-
ResilientStreamBuilder({Key? key, required Stream<
T> streamFactory(), required Widget builder(BuildContext, ResilienceSnapshot<T> ), ResiliencePipelineBuilder pipelineBuilder(ResiliencePipelineBuilder)?, Widget loadingBuilder(BuildContext)?, Widget errorBuilder(BuildContext, Object, StackTrace?)?, int maxReconnectAttempts = 5, Duration reconnectDelay = const Duration(seconds: 2)}) -
const
Properties
-
builder
→ Widget Function(BuildContext, ResilienceSnapshot<
T> ) -
Builder called on every snapshot change.
final
- errorBuilder → Widget Function(BuildContext, Object, StackTrace?)?
-
Optional widget on error.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- loadingBuilder → Widget Function(BuildContext)?
-
Optional widget while connecting.
final
- maxReconnectAttempts → int
-
Maximum reconnect attempts. 0 means unlimited.
final
- pipelineBuilder → ResiliencePipelineBuilder Function(ResiliencePipelineBuilder)?
-
Optional pipeline customizer. Used to wrap each re-subscription attempt.
final
- reconnectDelay → Duration
-
Base delay between reconnect attempts.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
streamFactory
→ Stream<
T> Function() -
Factory that creates a fresh stream on each (re)connection attempt.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< ResilientStreamBuilder< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited